Re: [PATCH 5/9] [media] redrat3: enable carrier reports using wideband receiver

2016-10-31 Thread Sean Young
The wideband receiver is a little awkward on the redrat3. Data arrives
on a different endpoint, and the learning command must be reissued
every time data is learned.

Signed-off-by: Sean Young 
---
 drivers/media/rc/redrat3.c | 186 ++---
 1 file changed, 140 insertions(+), 46 deletions(-)

diff --git a/drivers/media/rc/redrat3.c b/drivers/media/rc/redrat3.c
index eaf374d..1882712 100644
--- a/drivers/media/rc/redrat3.c
+++ b/drivers/media/rc/redrat3.c
@@ -81,6 +81,8 @@
 #define RR3_RC_DET_ENABLE  0xbb
 /* Stop capture with the RC receiver */
 #define RR3_RC_DET_DISABLE 0xbc
+/* Start capture with the wideband receiver */
+#define RR3_MODSIG_CAPTURE 0xb2
 /* Return the status of RC detector capture */
 #define RR3_RC_DET_STATUS  0xbd
 /* Reset redrat */
@@ -105,8 +107,10 @@
 #define RR3_CLK_PER_COUNT  12
 /* (RR3_CLK / RR3_CLK_PER_COUNT) */
 #define RR3_CLK_CONV_FACTOR200
 /* USB bulk-in IR data endpoint address */
 #define RR3_BULK_IN_EP_ADDR0x82
 
 /* Size of the fixed-length portion of the signal */
 #define RR3_DRIVER_MAXLENS 128
@@ -207,15 +211,22 @@ struct redrat3_dev {
struct urb *flash_urb;
u8 flash_in_buf;
 
+   /* learning */
+   bool wideband;
+   struct usb_ctrlrequest learn_control;
+   struct urb *learn_urb;
+   u8 learn_buf;
+
/* save off the usb device pointer */
struct usb_device *udev;
 
/* the receive endpoint */
-   struct usb_endpoint_descriptor *ep_in;
+   struct usb_endpoint_descriptor *ep_narrow;
/* the buffer to receive data */
void *bulk_in_buf;
/* urb used to read ir data */
-   struct urb *read_urb;
+   struct urb *narrow_urb;
+   struct urb *wide_urb;
 
/* the send endpoint */
struct usb_endpoint_descriptor *ep_out;
@@ -236,23 +247,6 @@ struct redrat3_dev {
char phys[64];
 };
 
-/*
- * redrat3_issue_async
- *
- *  Issues an async read to the ir data in port..
- *  sets the callback to be redrat3_handle_async
- */
-static void redrat3_issue_async(struct redrat3_dev *rr3)
-{
-   int res;
-
-   res = usb_submit_urb(rr3->read_urb, GFP_ATOMIC);
-   if (res)
-   dev_dbg(rr3->dev,
-   "%s: receive request FAILED! (res %d, len %d)\n",
-   __func__, res, rr3->read_urb->transfer_buffer_length);
-}
-
 static void redrat3_dump_fw_error(struct redrat3_dev *rr3, int code)
 {
if (!rr3->transmitting && (code != 0x40))
@@ -367,6 +361,14 @@ static void redrat3_process_ir_data(struct redrat3_dev 
*rr3)
 
mod_freq = redrat3_val_to_mod_freq(>irdata);
dev_dbg(dev, "Got mod_freq of %u\n", mod_freq);
+   if (mod_freq && rr3->wideband) {
+   DEFINE_IR_RAW_EVENT(ev);
+
+   ev.carrier_report = 1;
+   ev.carrier = mod_freq;
+
+   ir_raw_event_store(rr3->rc, );
+   }
 
/* process each rr3 encoded byte into an int */
sig_size = be16_to_cpu(rr3->irdata.sig_size);
@@ -449,19 +451,31 @@ static int redrat3_enable_detector(struct redrat3_dev 
*rr3)
return -EIO;
}
 
-   redrat3_issue_async(rr3);
+   ret = usb_submit_urb(rr3->narrow_urb, GFP_KERNEL);
+   if (ret) {
+   dev_err(rr3->dev, "narrow band urb failed: %d", ret);
+   return ret;
+   }
 
-   return 0;
+   ret = usb_submit_urb(rr3->wide_urb, GFP_KERNEL);
+   if (ret)
+   dev_err(rr3->dev, "wide band urb failed: %d", ret);
+
+   return ret;
 }
 
 static inline void redrat3_delete(struct redrat3_dev *rr3,
  struct usb_device *udev)
 {
-   usb_kill_urb(rr3->read_urb);
+   usb_kill_urb(rr3->narrow_urb);
+   usb_kill_urb(rr3->wide_urb);
usb_kill_urb(rr3->flash_urb);
-   usb_free_urb(rr3->read_urb);
+   usb_kill_urb(rr3->learn_urb);
+   usb_free_urb(rr3->narrow_urb);
+   usb_free_urb(rr3->wide_urb);
usb_free_urb(rr3->flash_urb);
-   usb_free_coherent(udev, le16_to_cpu(rr3->ep_in->wMaxPacketSize),
+   usb_free_urb(rr3->learn_urb);
+   usb_free_coherent(udev, le16_to_cpu(rr3->ep_narrow->wMaxPacketSize),
  rr3->bulk_in_buf, rr3->dma_in);
 
kfree(rr3);
@@ -694,9 +708,19 @@ static void redrat3_handle_async(struct urb *urb)
switch (urb->status) {
case 0:
ret = redrat3_get_ir_data(rr3, urb->actual_length);
+   if (!ret && rr3->wideband && !rr3->learn_urb->hcpriv) {
+   ret = usb_submit_urb(rr3->learn_urb, GFP_ATOMIC);
+   if (ret)
+   dev_err(rr3->dev, "Failed to submit learning 
urb: %d",
+

Re: [PATCH 5/9] [media] redrat3: enable carrier reports using wideband receiver

2016-10-31 Thread kbuild test robot
Hi Sean,

[auto build test WARNING on linuxtv-media/master]
[also build test WARNING on next-20161028]
[cannot apply to v4.9-rc3]
[if your patch is applied to the wrong git tree, please drop us a note to help 
improve the system]
[Suggest to use git(>=2.9.0) format-patch --base= (or --base=auto for 
convenience) to record what (public, well-known) commit your patch series was 
built on]
[Check https://git-scm.com/docs/git-format-patch for more information]

url:
https://github.com/0day-ci/linux/commits/Sean-Young/Various-IR-fixes/20161101-023658
base:   git://linuxtv.org/media_tree.git master
config: x86_64-randconfig-x014-201644 (attached as .config)
compiler: gcc-6 (Debian 6.2.0-3) 6.2.0 20160901
reproduce:
# save the attached .config to linux build tree
make ARCH=x86_64 

All warnings (new ones prefixed by >>):

   drivers/media/rc/redrat3.c: In function 'redrat3_learn_complete':
>> drivers/media/rc/redrat3.c:903:6: warning: unused variable 'ret' 
>> [-Wunused-variable]
 int ret;
 ^~~

vim +/ret +903 drivers/media/rc/redrat3.c

   887  
   888  rr3->wideband = enable != 0;
   889  
   890  if (enable) {
   891  ret = usb_submit_urb(rr3->learn_urb, GFP_KERNEL);
   892  if (ret)
   893  dev_err(rr3->dev, "Failed to submit learning 
urb: %d",
   894  
ret);
   895  }
   896  
   897  return ret;
   898  }
   899  
   900  static void redrat3_learn_complete(struct urb *urb)
   901  {
   902  struct redrat3_dev *rr3 = urb->context;
 > 903  int ret;
   904  
   905  switch (urb->status) {
   906  case 0:
   907  break;
   908  case -ECONNRESET:
   909  case -ENOENT:
   910  case -ESHUTDOWN:
   911  usb_unlink_urb(urb);

---
0-DAY kernel test infrastructureOpen Source Technology Center
https://lists.01.org/pipermail/kbuild-all   Intel Corporation


.config.gz
Description: application/gzip


[PATCH 5/9] [media] redrat3: enable carrier reports using wideband receiver

2016-10-31 Thread Sean Young
The wideband receiver is a little awkward on the redrat3. Data arrives
on a different endpoint, and the learning command must be reissued
every time data is learned.

Signed-off-by: Sean Young 
---
 drivers/media/rc/redrat3.c | 184 ++---
 1 file changed, 140 insertions(+), 44 deletions(-)
@@ -105,8 +107,10 @@
 /* (RR3_CLK / RR3_CLK_PER_COUNT) */
 #define RR3_CLK_CONV_FACTOR200
-/* USB bulk-in IR data endpoint address */
-#define RR3_BULK_IN_EP_ADDR0x82
+/* USB bulk-in wideband IR data endpoint address */
+#define RR3_WIDE_IN_EP_ADDR0x81
+/* USB bulk-in narrowband IR data endpoint address */
+#define RR3_NARROW_IN_EP_ADDR  0x82
 
 /* Size of the fixed-length portion of the signal */

diff --git a/drivers/media/rc/redrat3.c b/drivers/media/rc/redrat3.c
index eaf374d..4370d21 100644
--- a/drivers/media/rc/redrat3.c
+++ b/drivers/media/rc/redrat3.c
@@ -81,6 +81,8 @@
 #define RR3_RC_DET_ENABLE  0xbb
 /* Stop capture with the RC receiver */
 #define RR3_RC_DET_DISABLE 0xbc
+/* Start capture with the wideband receiver */
+#define RR3_MODSIG_CAPTURE 0xb2
 /* Return the status of RC detector capture */
 #define RR3_RC_DET_STATUS  0xbd
 /* Reset redrat */
@@ -105,8 +107,10 @@
 #define RR3_CLK_PER_COUNT  12
 /* (RR3_CLK / RR3_CLK_PER_COUNT) */
 #define RR3_CLK_CONV_FACTOR200
 /* USB bulk-in IR data endpoint address */
 #define RR3_BULK_IN_EP_ADDR0x82
 
 /* Size of the fixed-length portion of the signal */
 #define RR3_DRIVER_MAXLENS 128
@@ -207,15 +211,22 @@ struct redrat3_dev {
struct urb *flash_urb;
u8 flash_in_buf;
 
+   /* learning */
+   bool wideband;
+   struct usb_ctrlrequest learn_control;
+   struct urb *learn_urb;
+   u8 learn_buf;
+
/* save off the usb device pointer */
struct usb_device *udev;
 
/* the receive endpoint */
-   struct usb_endpoint_descriptor *ep_in;
+   struct usb_endpoint_descriptor *ep_narrow;
/* the buffer to receive data */
void *bulk_in_buf;
/* urb used to read ir data */
-   struct urb *read_urb;
+   struct urb *narrow_urb;
+   struct urb *wide_urb;
 
/* the send endpoint */
struct usb_endpoint_descriptor *ep_out;
@@ -236,23 +247,6 @@ struct redrat3_dev {
char phys[64];
 };
 
-/*
- * redrat3_issue_async
- *
- *  Issues an async read to the ir data in port..
- *  sets the callback to be redrat3_handle_async
- */
-static void redrat3_issue_async(struct redrat3_dev *rr3)
-{
-   int res;
-
-   res = usb_submit_urb(rr3->read_urb, GFP_ATOMIC);
-   if (res)
-   dev_dbg(rr3->dev,
-   "%s: receive request FAILED! (res %d, len %d)\n",
-   __func__, res, rr3->read_urb->transfer_buffer_length);
-}
-
 static void redrat3_dump_fw_error(struct redrat3_dev *rr3, int code)
 {
if (!rr3->transmitting && (code != 0x40))
@@ -367,6 +361,14 @@ static void redrat3_process_ir_data(struct redrat3_dev 
*rr3)
 
mod_freq = redrat3_val_to_mod_freq(>irdata);
dev_dbg(dev, "Got mod_freq of %u\n", mod_freq);
+   if (mod_freq && rr3->wideband) {
+   DEFINE_IR_RAW_EVENT(ev);
+
+   ev.carrier_report = 1;
+   ev.carrier = mod_freq;
+
+   ir_raw_event_store(rr3->rc, );
+   }
 
/* process each rr3 encoded byte into an int */
sig_size = be16_to_cpu(rr3->irdata.sig_size);
@@ -449,19 +451,31 @@ static int redrat3_enable_detector(struct redrat3_dev 
*rr3)
return -EIO;
}
 
-   redrat3_issue_async(rr3);
+   ret = usb_submit_urb(rr3->narrow_urb, GFP_KERNEL);
+   if (ret) {
+   dev_err(rr3->dev, "narrow band urb failed: %d", ret);
+   return ret;
+   }
 
-   return 0;
+   ret = usb_submit_urb(rr3->wide_urb, GFP_KERNEL);
+   if (ret)
+   dev_err(rr3->dev, "wide band urb failed: %d", ret);
+
+   return ret;
 }
 
 static inline void redrat3_delete(struct redrat3_dev *rr3,
  struct usb_device *udev)
 {
-   usb_kill_urb(rr3->read_urb);
+   usb_kill_urb(rr3->narrow_urb);
+   usb_kill_urb(rr3->wide_urb);
usb_kill_urb(rr3->flash_urb);
-   usb_free_urb(rr3->read_urb);
+   usb_kill_urb(rr3->learn_urb);
+   usb_free_urb(rr3->narrow_urb);
+   usb_free_urb(rr3->wide_urb);
usb_free_urb(rr3->flash_urb);
-   usb_free_coherent(udev, le16_to_cpu(rr3->ep_in->wMaxPacketSize),
+   usb_free_urb(rr3->learn_urb);
+   usb_free_coherent(udev, le16_to_cpu(rr3->ep_narrow->wMaxPacketSize),
  rr3->bulk_in_buf, rr3->dma_in);
 
kfree(rr3);
@@ -694,9 +708,19 @@ static void redrat3_handle_async(struct urb *urb)
switch (urb->status) {
case 0:
ret = redrat3_get_ir_data(rr3, urb->actual_length);
+   if (!ret && rr3->wideband && !rr3->learn_urb->hcpriv) {
+   ret = usb_submit_urb(rr3->learn_urb, GFP_ATOMIC);
+   if (ret)
+   dev_err(rr3->dev, "Failed to submit learning 
urb: %d",
+
@@ -105,8 +107,10 @@
 /* (RR3_CLK / RR3_CLK_PER_COUNT) */
 #define RR3_CLK_CONV_FACTOR200
-/* USB bulk-in IR data endpoint address */
-#define RR3_BULK_IN_EP_ADDR0x82
+/* USB bulk-in wideband IR data endpoint address */
+#define RR3_WIDE_IN_EP_ADDR0x81
+/* USB bulk-in narrowband IR data endpoint address */
+#define RR3_NARROW_IN_EP_ADDR  0x82
 
 /* Size of the fixed-length portion of the signal */